summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--CMakeLists.txt2
-rw-r--r--LICENSE4
-rw-r--r--README2
-rw-r--r--libpng-manual.txt10
-rw-r--r--libpng.322
-rw-r--r--libpngpf.34
-rw-r--r--png.52
-rw-r--r--png.c6
-rw-r--r--png.h20
-rw-r--r--pngconf.h2
-rw-r--r--pngpriv.h2
-rw-r--r--pngtest.c2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt12
-rwxr-xr-xscripts/libpng-config-head.in2
-rw-r--r--scripts/libpng.pc.in2
-rw-r--r--scripts/makefile.ne12bsd2
-rw-r--r--scripts/makefile.netbsd2
-rw-r--r--scripts/makefile.openbsd2
-rw-r--r--scripts/symbols.def2
21 files changed, 53 insertions, 53 deletions
diff --git a/CMakeLists.txt b/CMakeLists.txt
index af4d41a2e..40918bf9f 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -261,7 +261,7 @@ install(CODE ${PNG_CONFIG_INSTALL_CODE})
# SET UP LINKS
if(PNG_SHARED)
set_target_properties(${PNG_LIB_NAME} PROPERTIES
-# VERSION 15.${PNGLIB_RELEASE}.1.5.0rc05
+# VERSION 15.${PNGLIB_RELEASE}.1.5.0rc06
VERSION 15.${PNGLIB_RELEASE}.0
SOVERSION 15
CLEAN_DIRECT_OUTPUT 1)
diff --git a/LICENSE b/LICENSE
index 2456eafeb..df3a4c679 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.0rc05, December 31, 2010, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.0rc06, January 4, 2011, are
Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-December 31, 2010
+January 4, 2011
diff --git a/README b/README
index 8c8f91811..09385323f 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.0rc05 - December 31, 2010 (shared library 15.0)
+README for libpng version 1.5.0rc06 - January 4, 2011 (shared library 15.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/libpng-manual.txt b/libpng-manual.txt
index f2d28a67d..5466de28c 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.0rc05 - December 31, 2010
+ libpng version 1.5.0rc06 - January 4, 2011
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2010 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.0rc05 - December 31, 2010
+ libpng versions 0.97, January 1998, through 1.5.0rc06 - January 4, 2011
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2010 Glenn Randers-Pehrson
@@ -1050,7 +1050,7 @@ things.
As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
added. It expands the sample depth without changing tRNS to alpha.
-As of libpng version 1.5.0rc05, not all possible expansions are supported.
+As of libpng version 1.5.0rc06, not all possible expansions are supported.
In the following table, the 01 means grayscale with depth<8, 31 means
indexed with depth<8, other numerals represent the color type, "T" means
@@ -3810,13 +3810,13 @@ Other rules can be inferred by inspecting the libpng source.
XIV. Y2K Compliance in libpng
-December 31, 2010
+January 4, 2011
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.0rc05 are Y2K compliant. It is my belief that earlier
+upward through 1.5.0rc06 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index 9752e18cc..2fe8655a1 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "December 31, 2010"
+.TH LIBPNG 3 "January 4, 2011"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.0rc05
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.0rc06
.SH SYNOPSIS
\fI\fB
@@ -851,7 +851,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.0rc05 - December 31, 2010
+ libpng version 1.5.0rc06 - January 4, 2011
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2010 Glenn Randers-Pehrson
@@ -862,7 +862,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.0rc05 - December 31, 2010
+ libpng versions 0.97, January 1998, through 1.5.0rc06 - January 4, 2011
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2010 Glenn Randers-Pehrson
@@ -1901,7 +1901,7 @@ things.
As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
added. It expands the sample depth without changing tRNS to alpha.
-As of libpng version 1.5.0rc05, not all possible expansions are supported.
+As of libpng version 1.5.0rc06, not all possible expansions are supported.
In the following table, the 01 means grayscale with depth<8, 31 means
indexed with depth<8, other numerals represent the color type, "T" means
@@ -4661,13 +4661,13 @@ Other rules can be inferred by inspecting the libpng source.
.SH XIV. Y2K Compliance in libpng
-December 31, 2010
+January 4, 2011
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.0rc05 are Y2K compliant. It is my belief that earlier
+upward through 1.5.0rc06 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
@@ -4848,7 +4848,7 @@ the first widely used release:
1.4.3 14 10403 14.so.14.3[.0]
1.4.4 14 10404 14.so.14.4[.0]
1.5.0beta01-58 15 10500 15.so.15.0[.0]
- 1.5.0rc01-04 15 10500 15.so.15.0[.0]
+ 1.5.0rc01-06 15 10500 15.so.15.0[.0]
Henceforth the source version will match the shared-library minor
and patch numbers; the shared-library major version number will be
@@ -4905,7 +4905,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.5.0rc05 - December 31, 2010:
+Libpng version 1.5.0rc06 - January 4, 2011:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -4928,7 +4928,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.0rc05, December 31, 2010, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.0rc06, January 4, 2011, are
Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -5027,7 +5027,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-December 31, 2010
+January 4, 2011
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index e82fa92df..64e205cc2 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "December 31, 2010"
+.TH LIBPNGPF 3 "January 4, 2011"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.0rc05
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.0rc06
(private functions)
.SH SYNOPSIS
\fB#include \fI"pngpriv.h"
diff --git a/png.5 b/png.5
index 03115dc09..bdc2bd6c3 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "December 31, 2010"
+.TH PNG 5 "January 4, 2011"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index bb502e208..0cf6d42bc 100644
--- a/png.c
+++ b/png.c
@@ -14,7 +14,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_0rc05 Your_png_h_is_not_version_1_5_0rc05;
+typedef png_libpng_version_1_5_0rc06 Your_png_h_is_not_version_1_5_0rc06;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -555,13 +555,13 @@ png_get_copyright(png_structp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.5.0rc05 - December 31, 2010" PNG_STRING_NEWLINE \
+ "libpng version 1.5.0rc06 - January 4, 2011" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2010 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.5.0rc05 - December 31, 2010\
+ return "libpng version 1.5.0rc06 - January 4, 2011\
Copyright (c) 1998-2010 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 1a3d40722..25b6fb97f 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.5.0rc05 - (PENDING RELEASE)
+ * libpng version 1.5.0rc06 - (PENDING RELEASE)
*
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngpriv.h b/pngpriv.h
index a14830490..44e4673a2 100644
--- a/pngpriv.h
+++ b/pngpriv.h
@@ -1,7 +1,7 @@
/* pngpriv.h - private declarations for use inside libpng
*
- * libpng version 1.5.0rc05 - (PENDING RELEASE)
+ * libpng version 1.5.0rc06 - (PENDING RELEASE)
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index e70a8492f..ed0c1200e 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1784,4 +1784,4 @@ main(int argc, char *argv[])
}
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_0rc05 Your_png_h_is_not_version_1_5_0rc05;
+typedef png_libpng_version_1_5_0rc06 Your_png_h_is_not_version_1_5_0rc06;
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index cacf9d45f..36f183cc2 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.5.0rc05 - December 31, 2010
+libpng version 1.5.0rc06 - January 4, 2011
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 3f36fbcbc..c83f9de39 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.5.0rc05 - December 31, 2010
+ * libpng version 1.5.0rc06 - January 4, 2011
*
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 0443982f3..fc55edb8d 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,9 +1,9 @@
-Makefiles for libpng version 1.5.0rc05 - December 31, 2010
+Makefiles for libpng version 1.5.0rc06 - January 4, 2011
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng15.so.15.1.5.0rc05)
+ (gcc, creates libpng15.so.15.1.5.0rc06)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -20,7 +20,7 @@ pnglibconf.h.prebuilt => Stores configuration settings
makefile.dec => DEC Alpha UNIX makefile
makefile.dj2 => DJGPP 2 makefile
makefile.elf => Linux/ELF makefile symbol versioning,
- (gcc, creates libpng15.so.15.1.5.0rc05)
+ (gcc, creates libpng15.so.15.1.5.0rc06)
makefile.freebsd => FreeBSD makefile
makefile.gcc => Generic gcc makefile
makefile.hpgcc => HPUX makefile using gcc
@@ -35,12 +35,12 @@ pnglibconf.h.prebuilt => Stores configuration settings
makefile.os2 => OS/2 Makefile (gcc and emx, requires libpng.def)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.sggcc => Silicon Graphics (gcc,
- creates libpng15.so.15.1.5.0rc05)
+ creates libpng15.so.15.1.5.0rc06)
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
makefile.solaris => Solaris 2.X makefile (gcc,
- creates libpng15.so.15.1.5.0rc05)
+ creates libpng15.so.15.1.5.0rc06)
makefile.so9 => Solaris 9 makefile (gcc,
- creates libpng15.so.15.1.5.0rc05)
+ creates libpng15.so.15.1.5.0rc06)
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.sunos => Sun makefile
makefile.32sunu => Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index da4785045..b194cbdeb 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
# Modeled after libxml-config.
-version=1.5.0rc05
+version=1.5.0rc06
prefix=""
libdir=""
libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index f601d25e2..f873e9afd 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@ includedir=@includedir@/libpng15
Name: libpng
Description: Loads and saves PNG files
-Version: 1.5.0rc05
+Version: 1.5.0rc06
Libs: -L${libdir} -lpng15
Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 7b57a1b92..f8f09c2f3 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include/libpng15
LIB= png15
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.5.0rc05
+SHLIB_MINOR= 1.5.0rc06
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index e620ba167..3e7b001c0 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include
LIB= png
SHLIB_MAJOR= 3
-SHLIB_MINOR= 1.5.0rc05
+SHLIB_MINOR= 1.5.0rc06
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index 8b5862669..5eedc675c 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@ LIBDIR= ${PREFIX}/lib
MANDIR= ${PREFIX}/man/cat
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.5.0rc05
+SHLIB_MINOR= 1.5.0rc06
LIB= png
SRCS= png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/symbols.def b/scripts/symbols.def
index 8886ccce5..9305463af 100644
--- a/scripts/symbols.def
+++ b/scripts/symbols.def
@@ -5,7 +5,7 @@
LIBRARY
EXPORTS
-;Version 1.5.0rc05
+;Version 1.5.0rc06
png_access_version_number @1
png_set_sig_bytes @2
png_sig_cmp @3
diff --git a/png.h b/png.h
index 1d29aa7ed..8175f9235 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.0rc05 - December 31, 2010
+ * libpng version 1.5.0rc06 - January 4, 2011
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.0rc05 - December 31, 2010: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -142,7 +142,7 @@
* 1.4.3 14 10403 14.so.14.3[.0]
* 1.4.4 14 10404 14.so.14.4[.0]
* 1.5.0beta01-58 15 10500 15.so.15.0[.0]
- * 1.5.0rc01-04 15 10500 15.so.15.0[.0]
+ * 1.5.0rc01-06 15 10500 15.so.15.0[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -174,7 +174,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.0rc05, December 31, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -286,13 +286,13 @@
* Y2K compliance in libpng:
* =========================
*
- * December 31, 2010
+ * January 4, 2011
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.0rc05 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -348,9 +348,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.0rc05"
+#define PNG_LIBPNG_VER_STRING "1.5.0rc06"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.0rc05 - December 31, 2010\n"
+ " libpng version 1.5.0rc06 - January 4, 2011\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -363,7 +363,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 05
+#define PNG_LIBPNG_VER_BUILD 06
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -505,7 +505,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_5_0rc05;
+typedef char* png_libpng_version_1_5_0rc06;
/* Three color definitions. The order of the red, green, and blue, (and the
* exact size) is not important, although the size of the fields need to
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.0rc05 - December 31, 2010: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.0rc06 - January 4, 2011: Glenn
* See also "Contributing Authors", below.
*
@@ -174,7 +174,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.0rc05, December 31, 2010, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.0rc06, January 4, 2011, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -286,13 +286,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.0rc05 are Y2K compliant. It is my belief that
+ * upward through 1.5.0rc06 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*